## Old initial selections with `initSelection`

Deprecated in Select2 4.0. This has been replaced by another option and is only available in the full builds of Select2.

In the past, Select2 required an option called `initSelection` that was defined whenever a custom data source was being used, allowing for the initial selection for the component to be determined. This has been replaced by the `current` method on the data adapter.

Key
  `initSelection`
Value
  A function taking a `callback`

Adapter
  `DataAdapter`
Decorator
  `InitSelection`